tiled.server.object\_cache.ObjectCache.available\_bytes
=======================================================

.. currentmodule:: tiled.server.object_cache

.. autoproperty:: ObjectCache.available_bytes